"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var toggle_directives_1 = require("../../commons/directives/toggle.directives");
var htmldom_service_1 = require("../../commons/services/htmldom.service");
var DropdownDirective = (function () {
    function DropdownDirective(elementRef) {
        this.elementRef = elementRef;
        this.useItemClickClose = true;
        this.displayChange = new core_1.EventEmitter();
        this.dropup = null;
        this.class = '';
    }
    DropdownDirective.prototype.onDocumentClick = function (dom) {
        if ((!this.isClose()) && (!this.elementRef.nativeElement.contains(dom))) {
            this.dismiss();
        }
    };
    DropdownDirective.prototype.ngOnInit = function () {
        this._class = this.class + ' btn-group' + (this.dropup === null ? '' : ' dropup');
    };
    DropdownDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.toggleDirective.target = this;
        if (!this.toggleDirective.dom.type) {
            this.toggleDirective.dom.type = 'button';
        }
        this.dropMenuDirective.onClick = function () {
            if (_this.useItemClickClose) {
                _this.toggle();
            }
        };
        this.dropMenuDirective.bind(this.toggleDirective.dom);
    };
    DropdownDirective.prototype.toggle = function () {
        this.dropMenuDirective.dom.style.display === 'block' ? this.dismiss() : this.present();
    };
    DropdownDirective.prototype.isClose = function () {
        return this.dropMenuDirective.isClose();
    };
    DropdownDirective.prototype.present = function () {
        var btn = this.toggleDirective.elementRef.nativeElement;
        var btnSize = [btn.clientWidth, btn.clientHeight];
        this.dropMenuDirective.setShow(this.dropup !== null, btnSize);
        this.displayChange.emit(false);
    };
    DropdownDirective.prototype.dismiss = function () {
        this.dropMenuDirective.setHidden();
        this.displayChange.emit(false);
    };
    DropdownDirective.decorators = [
        { type: core_1.Directive, args: [{
                    selector: "[tsDropdown]",
                    exportAs: 'tsDropdown',
                },] },
    ];
    DropdownDirective.ctorParameters = function () { return [
        { type: core_1.ElementRef }
    ]; };
    DropdownDirective.propDecorators = {
        dropup: [{ type: core_1.Input }],
        class: [{ type: core_1.Input }],
        useItemClickClose: [{ type: core_1.Input }],
        displayChange: [{ type: core_1.Output }],
        toggleDirective: [{ type: core_1.ContentChild, args: [core_1.forwardRef(function () { return toggle_directives_1.ToggleDirective; }),] }],
        dropMenuDirective: [{ type: core_1.ContentChild, args: [core_1.forwardRef(function () { return DropMenuDirective; }),] }],
        _class: [{ type: core_1.HostBinding, args: ['class',] }],
        onDocumentClick: [{ type: core_1.HostListener, args: ['document:click', ['$event.target'],] }]
    };
    return DropdownDirective;
}());
exports.DropdownDirective = DropdownDirective;
var DropMenuDirective = (function () {
    function DropMenuDirective(elementRef, html) {
        this.elementRef = elementRef;
        this.html = html;
        this.displayChange = new core_1.EventEmitter();
        this.class = 'dropdown-menu';
        this.offsetX = 0;
        this.offsetY = 4;
        this.modalSize = 0;
    }
    DropMenuDirective.prototype.ngAfterViewInit = function () {
        this.dom = this.elementRef.nativeElement;
        this.dom.style.top = '0';
        this.dom.style.left = '0';
    };
    DropMenuDirective.prototype.setPostion = function (dropup, btnSize) {
        if (dropup === void 0) { dropup = false; }
        if (dropup !== null && dropup !== false) {
            this.dom.style.transform = "translate3d(" + this.offsetX + "px, -" + (this.dom.clientHeight + this.offsetY) + "px, 0px)";
        }
        else {
            this.dom.style.transform = "translate3d(" + this.offsetX + "px, " + (btnSize[1] + this.offsetY) + "px, 0px)";
        }
        if (this.modalSize > 0) {
            var overflowX = this.overflowX();
            if (dropup !== null && dropup !== false) {
                this.dom.style.transform = "translate3d(" + this.offsetX + "px, -" + (this.dom.clientHeight + this.offsetY) + "px, 0px)";
            }
            else {
                this.dom.style.transform = "translate3d(" + (this.offsetX - overflowX) + "px, " + (btnSize[1] + this.offsetY) + "px, 0px)";
            }
        }
    };
    DropMenuDirective.prototype.overflowX = function () {
        var point = this.html.getPosition(this.dom);
        var w = this.html.getWidth(this.dom);
        var compare = window.innerWidth < this.modalSize ? window.innerWidth : (window.innerWidth + this.modalSize) / 2;
        var offset = (point.x + w) - compare;
        return offset > 0 ? offset + 20 : 0;
    };
    DropMenuDirective.prototype.bind = function (toggle) {
        this.toggleDom = toggle;
    };
    DropMenuDirective.prototype.setShow = function (dropup, btnSize) {
        if (dropup === void 0) { dropup = false; }
        this.dom.style.display = 'block';
        this.setPostion(dropup, btnSize);
        this.displayChange.emit(true);
    };
    DropMenuDirective.prototype.setHidden = function () {
        this.dom.style.display = '';
        this.displayChange.emit(false);
    };
    DropMenuDirective.prototype.isClose = function () {
        return this.dom.style.display !== 'block';
    };
    DropMenuDirective.decorators = [
        { type: core_1.Directive, args: [{
                    selector: "[tsDropMenu]",
                    exportAs: "tsDropMenu",
                },] },
    ];
    DropMenuDirective.ctorParameters = function () { return [
        { type: core_1.ElementRef },
        { type: htmldom_service_1.HtmlDomService }
    ]; };
    DropMenuDirective.propDecorators = {
        modalSize: [{ type: core_1.Input }],
        offsetX: [{ type: core_1.Input }],
        offsetY: [{ type: core_1.Input }],
        displayChange: [{ type: core_1.Output }],
        class: [{ type: core_1.HostBinding, args: ['class',] }],
        onClick: [{ type: core_1.HostListener, args: ['click',] }]
    };
    return DropMenuDirective;
}());
exports.DropMenuDirective = DropMenuDirective;
//# sourceMappingURL=dropdown.directive.js.map