"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var modal_component_1 = require("./modal.component");
var rxjs_1 = require("rxjs");
var ModalService = (function () {
    function ModalService(applicationRef, componentFactoryResolver, injector) {
        this.applicationRef = applicationRef;
        this.componentFactoryResolver = componentFactoryResolver;
        this.injector = injector;
    }
    ModalService.prototype.init = function (ref) {
        var _this = this;
        this.baseComponent = this.componentFactoryResolver.resolveComponentFactory(modal_component_1.ModalComponent);
        this.windowCmptRef = this.baseComponent.create(this.injector, [[ref]]);
        this.applicationRef.attachView(this.windowCmptRef.hostView);
        this.containerEl = document.querySelector('body');
        this.containerEl.appendChild(this.windowCmptRef.location.nativeElement);
        this.windowCmptRef.instance.closeHandle = function () {
            _this.dismiss();
        };
    };
    ModalService.prototype.create = function (content, options) {
        this.loadComponent(content);
        this.options = options;
        return this;
    };
    ModalService.prototype.loadComponent = function (content) {
        var componentFactory = this.componentFactoryResolver.resolveComponentFactory(content);
        var componentRef = componentFactory.create(this.injector);
        this.applicationRef.attachView(componentRef.hostView);
        this.modal = componentRef;
    };
    Object.defineProperty(ModalService.prototype, "instance", {
        get: function () {
            return this.modal.instance;
        },
        enumerable: true,
        configurable: true
    });
    ModalService.prototype.close = function (params) {
        this.windowCmptRef.destroy();
        if (this.handle) {
            this.handle.next(params);
        }
    };
    ModalService.prototype.dismiss = function () {
        this.windowCmptRef.destroy();
    };
    ModalService.prototype.open = function () {
        this.init(this.modal.location.nativeElement);
        if (this.options !== undefined) {
            this.windowCmptRef.instance.size = this.options.size || '';
            this.windowCmptRef.instance.center = this.options.center || false;
            this.windowCmptRef.instance.scroll = this.options.scroll || 'out';
        }
        this.handle = new rxjs_1.Subject();
        return this.handle.asObservable();
    };
    ModalService.decorators = [
        { type: core_1.Injectable },
    ];
    ModalService.ctorParameters = function () { return [
        { type: core_1.ApplicationRef },
        { type: core_1.ComponentFactoryResolver },
        { type: core_1.Injector }
    ]; };
    return ModalService;
}());
exports.ModalService = ModalService;
//# sourceMappingURL=modal.service.js.map