"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var attr_class_1 = require("../../commons/extends/attr.class");
var dropdown_directive_1 = require("../dropdown/dropdown.directive");
var forms_1 = require("@angular/forms");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var SearchComponent = (function (_super) {
    __extends(SearchComponent, _super);
    function SearchComponent(elementRef) {
        var _this = _super.call(this) || this;
        _this.elementRef = elementRef;
        _this.title = '';
        _this.activeItems = [];
        _this.changeInside = false;
        _this.subject = new rxjs_1.Subject();
        _this.applyChange = function (value) { };
        _this.placeholder = 'Select...';
        _this.emptyLabel = 'No results found.';
        _this.searchLabel = 'Search...';
        return _this;
    }
    SearchComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.items$ = this.subject.pipe(operators_1.debounceTime(300), operators_1.distinctUntilChanged(), operators_1.switchMap(function (key) { return _this.search(key); }));
    };
    SearchComponent.prototype.ngAfterViewInit = function () {
        var dom = this.elementRef.nativeElement;
        dom.classList.add('form-control', 'p-0');
        if (this.sm !== null) {
            dom.classList.add('form-control-sm');
        }
        if (this.lg !== null) {
            dom.classList.add('form-control-lg');
        }
    };
    SearchComponent.prototype.doSearch = function (key) {
        if (key.trim()) {
            this.subject.next(key);
        }
    };
    SearchComponent.prototype.writeValue = function (values) {
        if (values === null || values === undefined) {
            values = [];
        }
        this.activeItems = values;
    };
    SearchComponent.prototype.registerOnChange = function (fn) { this.applyChange = fn; };
    SearchComponent.prototype.registerOnTouched = function (fn) { this.applyChange = fn; };
    SearchComponent.prototype.cleanSearch = function () {
        console.log(this.input);
        this.input.nativeElement.value = '';
    };
    SearchComponent.prototype.setValue = function (item) {
        var _this = this;
        var index = this.activeItems.findIndex(function (e) { return e.value === item.value; });
        if (index < 0) {
            this.activeItems.push(item);
        }
        else {
            this.activeItems.splice(index, 1);
        }
        this.applyChange(this.activeItems);
        setTimeout(function () {
            if (!_this.dropdown.isClose()) {
                _this.dropdown.present();
            }
        });
    };
    SearchComponent.prototype.isActiveItem = function (item) {
        return this.activeItems.findIndex(function (e) { return e.value === item.value; }) >= 0;
    };
    SearchComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: '*[tsSearch]',
                    template: "\n    <div tsDropdown  #tsDropdown=\"tsDropdown\" (displayChange)=\"cleanSearch()\" class=\"w-100\" [useItemClickClose]=\"false\">\n        <div tsToggle\n            [class.p-0]=\"activeItems.length>0\"\n            [class.p-2]=\"activeItems.length<=0\"\n            class=\"pointer w-100\">\n            <span class=\"text-muted\" *ngIf=\"activeItems.length<=0\">{{placeholder}}</span>\n            <span class=\"badge p-2 m-1 no-select {{badgeClass}}\" *ngFor=\"let active of activeItems\">\n                <i (click)=\"setValue(active)\" class=\"fa fa-fw fa-close\"></i>\n                {{active.text}}\n            </span>\n        </div>\n        <div tsDropMenu [style.width]=\"'100%'\">\n            <div class=\"w-100 ts-select-item\">\n                <div class=\"pl-2 pb-2 pr-2\">\n                    <input #searchBox\n                        (keyup)=\"doSearch(searchBox.value)\"\n                        [placeholder]=\"searchLabel\"\n                        class=\"form-control\" type=\"text\">\n               </div>\n                <div *ngFor=\"let item of items$ | async\"\n                    (click)=\"setValue(item)\"\n                    class=\"dropdown-item pointer no-select {{isActiveItem(item)?textClass:''}}\">\n                    <div class=\"d-table w-100\">\n                        <div class=\"d-table-cell\" [innerHTML]=\"item.content||item.text\"></div>\n                        <div class=\"d-table-cell text-right\" *ngIf=\"isActiveItem(item)\">\n                            <i class=\"fa fa-fw fa-check\"></i>\n                        </div>\n                    </div>\n                </div>\n            </div>\n        </div>\n    </div>",
                    styles: [
                        ".ts-select-item {\n            max-height: 270px;\n            overflow-y: auto;\n        }\n        .dropdown-item.active,\n        .dropdown-item:active{\n            color: #343a40 !important;\n            background: #f8f9fa !important;\n        }\n        .dropdown-item:after{\n            text-align:center;\n        }"
                    ],
                    providers: [{
                            provide: forms_1.NG_VALUE_ACCESSOR,
                            useExisting: core_1.forwardRef(function () { return SearchComponent; }),
                            multi: true
                        }]
                },] },
    ];
    SearchComponent.ctorParameters = function () { return [
        { type: core_1.ElementRef }
    ]; };
    SearchComponent.propDecorators = {
        search: [{ type: core_1.Input }],
        placeholder: [{ type: core_1.Input }],
        emptyLabel: [{ type: core_1.Input }],
        searchLabel: [{ type: core_1.Input }],
        dropdown: [{ type: core_1.ViewChild, args: ['tsDropdown',] }],
        input: [{ type: core_1.ViewChild, args: ['searchBox',] }]
    };
    return SearchComponent;
}(attr_class_1.DomAttr));
exports.SearchComponent = SearchComponent;
//# sourceMappingURL=search.component.js.map