"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var ToastComponent = (function () {
    function ToastComponent(config) {
        this.config = config;
        this.maxLength = 5;
        this.dValue = 500;
        this.show = true;
        this.toasts = new Array();
        this.position = this.config.position;
        this.maxLength = this.config.maxLength;
        this.timer = null;
    }
    ToastComponent.prototype.addToast = function (toast) {
        var _this = this;
        if (this.timer === null) {
            this.timer = setInterval(function () {
                _this.checkTimeOut();
            }, this.dValue);
        }
        if (this.toasts.length > this.maxLength) {
            this.toasts.shift();
        }
        var index = this.toasts.findIndex(function (e) { return e.message === toast.message && e.title === toast.title; });
        if (index >= 0) {
            this.toasts.splice(index, 1);
        }
        this.toasts.push(toast);
        this.show = true;
    };
    ToastComponent.prototype.removeToast = function (toast) {
        this.toasts.splice(this.toasts.indexOf(toast), 1);
    };
    ToastComponent.prototype.checkTimeOut = function () {
        var _this = this;
        this.toasts.forEach(function (toast) {
            toast.cx += _this.dValue;
        });
        this.toasts = this.toasts.filter(function (toast) { return toast.timeout > toast.cx || toast.timeout === -1; });
        if (this.toasts.length <= 0) {
            clearInterval(this.timer);
            this.timer = null;
        }
    };
    ToastComponent.prototype.ngOnDestroy = function () {
        if (this.timer !== null) {
            clearInterval(this.timer);
            this.timer = null;
        }
    };
    ToastComponent.decorators = [
        { type: core_1.Component, args: [{
                    template: "\n    <div *ngIf=\"show\" class=\"{{position}} position-fixed alert m-2\" style=\"width:20rem;z-index:9999\">\n        <div *ngFor=\"let toast of toasts\"\n            class=\"ts-toast animated fadeInUp alert rounded-0 bg-white {{toast.color}}\"\n            [class.ts-op-hidden]=\"(toast.timeout - toast.cx)<=1000\">\n            <h6 class=\"alert-heading\">\n                <i class=\"fa fa-fw {{toast.icon}}\"></i>\n                <span class=\"text-dark\">{{toast.title}}</span>\n                <span (click)=\"removeToast(toast)\" class=\"pointer pull-right\" style=\"opacity: 0.8;\">&times;</span>\n            </h6>\n            <hr class=\"mb-2\">\n            <p class=\"mb-0 mt-0 text-dark\">{{toast.message}}</p>\n        </div>\n    </div>\n    ",
                    styles: ["\n        .animated {\n            animation-duration: 0.5s;\n            animation-fill-mode: both;\n        }\n        @keyframes fadeInUp {\n            from {\n              opacity: 0;\n              transform: translate3d(0, 100%, 0);\n            }\n            to {\n              opacity: 1;\n              transform: translate3d(0, 0, 0);\n            }\n        }\n        .fadeInUp {\n            animation-name: fadeInUp;\n        }\n        .ts-toast{\n            box-shadow: 1px 2px 3px #ccc;\n            border-width: 0;\n            border-left-width: 3px;\n        }\n        .close {\n            cursor:pointer;\n        }\n        .ts-top {\n            top:0\n        }\n        .ts-bottom {\n            bottom:0\n        }\n        .ts-left {\n            left:0\n        }\n        .ts-right {\n            right:0;\n        }\n        .ts-op-hidden{\n            opacity:0;\n            transition: opacity 1s;\n        }\n        ",
                    ]
                },] },
    ];
    ToastComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: core_1.Inject, args: ['DEFAULT_CONFIG',] }] }
    ]; };
    return ToastComponent;
}());
exports.ToastComponent = ToastComponent;
//# sourceMappingURL=toast.component.js.map