"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var toast_component_1 = require("./toast.component");
var toast_class_1 = require("./toast.class");
var ToastService = (function () {
    function ToastService(applicationRef, componentFactoryResolver, config, injector) {
        this.applicationRef = applicationRef;
        this.componentFactoryResolver = componentFactoryResolver;
        this.config = config;
        this.injector = injector;
    }
    ToastService.prototype.init = function () {
        if (this.baseComponent !== undefined || this.baseComponent != null) {
            return;
        }
        this.baseComponent = this.componentFactoryResolver.resolveComponentFactory(toast_component_1.ToastComponent);
        this.windowCmptRef = this.baseComponent.create(this.injector);
        this.applicationRef.attachView(this.windowCmptRef.hostView);
        var containerEl = document.querySelector('body');
        containerEl.appendChild(this.windowCmptRef.location.nativeElement);
    };
    ToastService.prototype.create = function (title, message, options) {
        this.init();
        this.windowCmptRef.instance.addToast(new toast_class_1.Toast(title, message, options.color, options.icon, options.timeout || this.config.timeout));
    };
    ToastService.prototype.info = function (title, message, timer) {
        this.create(title, message, { color: 'border-info', icon: 'text-info fa-info-circle', timeout: timer || this.config.timeout });
    };
    ToastService.prototype.success = function (title, message, timer) {
        this.create(title, message, {
            color: 'border-success',
            icon: 'text-success fa-check-circle', timeout: timer || this.config.timeout
        });
    };
    ToastService.prototype.danger = function (title, message, timer) {
        this.create(title, message, {
            color: 'border-danger',
            icon: 'text-danger fa-exclamation-circle', timeout: timer || this.config.timeout
        });
    };
    ToastService.prototype.warning = function (title, message, timer) {
        this.create(title, message, {
            color: 'border-warning',
            icon: 'text-warning fa-exclamation-triangle', timeout: timer || this.config.timeout
        });
    };
    ToastService.decorators = [
        { type: core_1.Injectable },
    ];
    ToastService.ctorParameters = function () { return [
        { type: core_1.ApplicationRef },
        { type: core_1.ComponentFactoryResolver },
        { type: undefined, decorators: [{ type: core_1.Inject, args: ['DEFAULT_CONFIG',] }] },
        { type: core_1.Injector }
    ]; };
    return ToastService;
}());
exports.ToastService = ToastService;
//# sourceMappingURL=toast.service.js.map