"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var rxjs_1 = require("rxjs");
var script_service_1 = require("../../commons/services/script.service");
var map_config_1 = require("./map.config");
var operators_1 = require("rxjs/operators");
var MapService = (function () {
    function MapService(mapConfig, script) {
        var _this = this;
        this.mapConfig = mapConfig;
        this.script = script;
        this.ready = false;
        var sub = new rxjs_1.Subject();
        this.loadHandle = sub.asObservable();
        if (!window.AMap) {
            window.aMapLoadCallBack = function () {
                _this.amap = window.AMap;
                _this.ready = true;
                sub.next(window.AMap);
                sub.complete();
            };
            this.script.load("https://webapi.amap.com/maps?v=1.4.3&key=" + this.mapConfig.appKey + "&callback=aMapLoadCallBack");
        }
        else {
            this.ready = true;
        }
    }
    MapService.prototype.doFuc = function (func) {
        var _this = this;
        if (this.ready) {
            func(this.amap);
        }
        else {
            this.loadHandle.subscribe({ complete: function () { return func(_this.amap); } });
        }
    };
    MapService.prototype.getPositionByAddress = function (address) {
        return this.doAMapGeocoder().pipe(operators_1.switchMap(function (geocoder) {
            return rxjs_1.fromEventPattern((function (handle) {
                geocoder.getLocation(address, function (status, result) {
                    if (status === 'complete' && result.info === 'OK') {
                        handle({ result: true, datas: result });
                    }
                    else {
                        handle({ result: false, datas: result });
                    }
                });
            }));
        }));
    };
    MapService.prototype.getAddressByPosition = function (point) {
        return this.doAMapGeocoder().pipe(operators_1.switchMap(function (geocoder) {
            return rxjs_1.fromEventPattern((function (handle) {
                geocoder.getAddress(point, function (status, result) {
                    if (status === 'complete' && result.info === 'OK') {
                        handle({ result: true, datas: result });
                    }
                    else {
                        handle({ result: false, datas: result });
                    }
                });
            }));
        }));
    };
    MapService.prototype.doAMapGeocoder = function (options) {
        var _this = this;
        if (options === void 0) { options = {}; }
        return rxjs_1.Observable.create(function (observer) {
            _this.doFuc(function () {
                window.AMap.service('AMap.Geocoder', function () {
                    var geocoder = new window.AMap.Geocoder(options);
                    observer.next(geocoder);
                    observer.complete();
                });
            });
        });
    };
    MapService.prototype.geometryUtil = function (callback) {
        this.doFuc(function (amap) {
            callback(amap.GeometryUtil, amap);
        });
    };
    MapService.decorators = [
        { type: core_1.Injectable },
    ];
    MapService.ctorParameters = function () { return [
        { type: map_config_1.MapConfig },
        { type: script_service_1.ScriptService }
    ]; };
    return MapService;
}());
exports.MapService = MapService;
//# sourceMappingURL=map.service.js.map