"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var script_service_1 = require("./../../commons/services/script.service");
var QuillDirective = (function () {
    function QuillDirective(elementRef, script, cdRef, srcs) {
        this.elementRef = elementRef;
        this.script = script;
        this.cdRef = cdRef;
        this.srcs = srcs;
        this.load = new core_1.EventEmitter();
        this.contentChange = new core_1.EventEmitter();
        this.noUpdateContent = false;
        this.enable = true;
        this.content = '';
        this.options = { theme: 'snow', placeholder: 'Compose an epic...' };
    }
    QuillDirective.prototype.ngOnChanges = function (change) {
        this.updateContent();
    };
    QuillDirective.prototype.ngOnInit = function () {
        this.script.loads(this.srcs, !!window.Quill);
    };
    QuillDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.textarea = this.elementRef.nativeElement;
        this.script.complete(function () {
            _this.quill = new window.Quill(_this.textarea, _this.options);
            _this.ready = true;
            _this.updateContent();
            _this.quill.on('text-change', function () {
                _this.noUpdateContent = true;
                _this.contentChange.emit(_this.quill.root.innerHTML);
            });
            _this.quill.enable(_this.enable);
        });
    };
    QuillDirective.prototype.updateContent = function () {
        if (this.ready && !this.noUpdateContent) {
            this.quill.enable(this.enable);
            this.quill.clipboard.dangerouslyPasteHTML(this.content);
            this.cdRef.detectChanges();
        }
        this.noUpdateContent = false;
    };
    QuillDirective.decorators = [
        { type: core_1.Directive, args: [{
                    selector: '*[tsQuill]',
                    exportAs: 'tsQuill',
                },] },
    ];
    QuillDirective.ctorParameters = function () { return [
        { type: core_1.ElementRef },
        { type: script_service_1.ScriptService },
        { type: core_1.ChangeDetectorRef },
        { type: Array, decorators: [{ type: core_1.Inject, args: ['QUILL_SCRIPT_SRCS',] }] }
    ]; };
    QuillDirective.propDecorators = {
        content: [{ type: core_1.Input }],
        enable: [{ type: core_1.Input }],
        options: [{ type: core_1.Input }],
        load: [{ type: core_1.Output }],
        contentChange: [{ type: core_1.Output }]
    };
    return QuillDirective;
}());
exports.QuillDirective = QuillDirective;
//# sourceMappingURL=quill.directive.js.map